@@ -30,6 +30,7 @@
 #include "rsvg-gz.h"
 #endif
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -124,7 +125,9 @@ rsvg_pixbuf_from_file_with_size_data_ex (RsvgHandle * handle,
 
 	if (!f)
 		{
-			/* FIXME: Set up error. */
+			g_set_error (error, G_FILE_ERROR,
+						 g_file_error_from_errno (errno),
+						 g_strerror (errno));
 			return NULL;
 		}
 	
@@ -154,13 +157,18 @@ rsvg_pixbuf_from_file_with_size_data (const gchar * file_name,
 
 	if (!f)
 		{
-			/* FIXME: Set up error. */
+			g_set_error (error, G_FILE_ERROR,
+						 g_file_error_from_errno (errno),
+						 g_strerror (errno));
 			return NULL;
 		}
 	
 	result = fread (chars, 1, SVG_BUFFER_SIZE, f);
 
 	if (result == 0) {
+		g_set_error (error, G_FILE_ERROR,
+					 g_file_error_from_errno (errno),
+					 g_strerror (errno));
 		fclose (f);
 		return NULL;
 	}
@@ -208,7 +216,9 @@ rsvg_pixbuf_from_file_with_size_data (const gchar * file_name,
  * by this call and must be freed by the caller.
  * 
  * Return value: A newly allocated #GdkPixbuf, or %NULL
- **/
+ *
+ * Since: 2.4
+ */
 GdkPixbuf  *
 rsvg_pixbuf_from_file_at_size_ex (RsvgHandle * handle,
 								  const gchar  *file_name,
@@ -237,7 +247,9 @@ rsvg_pixbuf_from_file_at_size_ex (RsvgHandle * handle,
  * freed by the caller.
  * 
  * Return value: A newly allocated #GdkPixbuf, or %NULL
- **/
+ *
+ * Since: 2.4
+ */
 GdkPixbuf  *
 rsvg_pixbuf_from_file_ex (RsvgHandle * handle,
 						  const gchar  *file_name,
@@ -261,7 +273,9 @@ rsvg_pixbuf_from_file_ex (RsvgHandle * handle,
  * call and must be freed by the caller.
  * 
  * Return value: A newly allocated #GdkPixbuf, or %NULL
- **/
+ *
+ * Since: 2.4
+ */
 GdkPixbuf  *
 rsvg_pixbuf_from_file_at_zoom_ex (RsvgHandle * handle,
 								  const gchar  *file_name,
@@ -296,7 +310,9 @@ rsvg_pixbuf_from_file_at_zoom_ex (RsvgHandle * handle,
  * must be freed by the caller.
  * 
  * Return value: A newly allocated #GdkPixbuf, or %NULL
- **/
+ *
+ * Since: 2.4
+ */
 GdkPixbuf  *
 rsvg_pixbuf_from_file_at_max_size_ex (RsvgHandle * handle,
 									  const gchar  *file_name,
@@ -331,7 +347,9 @@ rsvg_pixbuf_from_file_at_max_size_ex (RsvgHandle * handle,
  * Returned handle is closed by this call and must be freed by the caller.
  * 
  * Return value: A newly allocated #GdkPixbuf, or %NULL
- **/
+ *
+ * Since: 2.4
+ */
 GdkPixbuf  *
 rsvg_pixbuf_from_file_at_zoom_with_max_ex (RsvgHandle * handle,
 										   const gchar  *file_name,
